==> better-admin-ui-vue-0.0.1.tgz: package/es/components/Form/Form.mixin.js <==
import * as _vue from "vue";

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? Object(arguments[i]) : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

/**
 * @Date: 2020-05-20 09:42
 * @Author: Fioanna
 * @Description: 高级表单混入
 */
import AFormModel from 'ant-design-vue/es/form-model';
import AInputNumber from 'ant-design-vue/es/input-number';
import { Group as ARadioGroup } from 'ant-design-vue/es/radio';
import { isChooseType, getDefaultPlaceholder } from './constants';
import { formMixinProps } from './types';
import EDateRange from '../DateRange/DateRange';
import EInput from '../Input/Input';
import ESelect from '../Select/Select';
import ESuggestSelect from '../SuggestSelect/SuggestSelect';
import './style.less';
var AFormModelItem = AFormModel.Item;
export default {
  name: 'EFormMixin',
  components: {
    AFormModel: AFormModel,
    AFormModelItem: AFormModelItem,
    AInputNumber: AInputNumber,
    ARadioGroup: ARadioGroup,
    EDateRange: EDateRange,
    EInput: EInput,
    ESelect: ESelect,
    ESuggestSelect: ESuggestSelect
  },
  props: formMixinProps,
  data: function data() {
    return {
      fieldList: [],
      // 表单的itemName列表
      form: {},
      // 表单数据
      labelForm: {} // 选择器展示文字的集合

    };
  },
  computed: {
    // filedList是否有数据
    hasFieldList: function hasFieldList() {
      return this.fieldList && this.fieldList.length > 0;
    },
    // 表单v-bind的所有props
    formModelBind: function formModelBind() {
      return {
        model: this.form
      };
    }
  },
  watch: {
    list: function list(newVal) {
      this._parseFieldList(newVal, this.form);
    },
    // 先注释掉，如果打开会引起整个form的dom重新刷新。暂时没有测出问题
    formData: function formData(newVal) {
      if (newVal) {
        // 数据更新合并
        this.form = _extends({}, this.form, newVal);
      }
    }
  },
  created: function created() {
    this.validError = false;

    this._parseFieldList(this.list, this.formData);
  },
  methods: {
    /**
     * 解析表单参数列表,获取字典列表
     * @private
     */
    _parseFieldList: function _parseFieldList(list, formData) {
      var _this = this;

      if (list && list.length > 0) {
        var newForm = _extends({}, formData);

        var fieldList = [];
        this.list.forEach(function (item) {
          if (!item.hidden) {
            // 不隐藏的
            var type = item.type;
            var props = _objectSpread({}, item.props) || {}; // 如果item中有options时，则设置到props中去

            if (item.options) {
              props.options = _toConsumableArray(item.options);
            }

            var newItem = _objectSpread({}, item, {
              props: props
            }); // 如果原本没有palceholder则设置默认的palceholder


            if (!props.placeholder) {
              props.placeholder = item.placeholder || getDefaultPlaceholder(type) + item.label;
            } // 如果必输，设置rules


            if (item.required) {
              newItem.rules = newForm.rules || [];
              newItem.rules.unshift({
                required: true,
                message: props.placeholder,
                trigger: isChooseType(type) ? 'change' : 'blur'
              });
            }

            props.disabled = _this._isDisabled(item); // 是否有对应类型解析数据到方法，有则调用

            var parseTypeMethodName = "_parse".concat(type);

            if (_this[parseTypeMethodName]) {
              _this[parseTypeMethodName](item, props, newForm, newItem);
            }

            fieldList.push(newItem);
          }
        });
        this.fieldList = fieldList;
        this.form = newForm;

        this._doAfterParseFieldList();
      }
    },

    /**
     * 解析完表单项列表的操作，可继承修改
     * @private
     */
    _doAfterParseFieldList: function _doAfterParseFieldList() {},

    /**
     * 判断formItem是否不可编辑，可继承修改
     * @param fieldItem
     * @returns {boolean}
     * @private
     */
    _isDisabled: function _isDisabled(fieldItem) {
      if (fieldItem.props && fieldItem.props.disabled) {
        // 如果该项的属性就是不可编辑返回true
        return true;
      }

      return false;
    },
    // 下拉多选
    _parseSelect: function _parseSelect(item, props, newForm) {
      var _this2 = this;

      // 下拉选项，且有字典值则从协议获取数据
      if (item.dictId) {
        props.valueName = 'name';
        props.labelName = 'caption';
        this.getDictList(item.dictId).then(function (list) {
          _this2._refreshDictSelectList(list, item, props);
        })["catch"](function () {});
      } else {
        this._refreshSelectList(props.options, item, props);
      } // 下拉需要初始化值


      if (item.init && newForm[item.key] === undefined) {
        newForm[item.key] = props.options[0].value;
      }
    },
    // 单选
    _parseRadio: function _parseRadio(item, props, newForm) {
      // 单选需要初始化值
      if (item.init && newForm[item.key] === undefined) {
        newForm[item.key] = props.options[0].value;
      }
    },
    // 时间选择器
    _parseDateRange: function _parseDateRange(item, props, newForm, newItem) {
      var key = newItem.key;

      if (!newItem.keys) {
        newItem.keys = [key + '1', key + '2'];
      }

      var keys = newItem.keys;

      if (newForm[keys[0]] && newForm[keys[1]]) {
        newForm[key] = 'true';
      }
    },

    /**
     * 刷新普通下拉选项列表，可继承
     */
    // eslint-disable-next-line
    _refreshSelectList: function _refreshSelectList(selectList, item, props) {},

    /**
     * 刷新字典下拉选项列表，可继承
     */
    // eslint-disable-next-line
    _refreshDictSelectList: function _refreshDictSelectList(selectList, item, props) {
      var itemDom = this.$refs[item.key]; // 直接更新下拉组件中的数据

      if (itemDom) {
        itemDom.setOptionList(selectList);
      }
    },
    // 初始化表单各项内容
    _renderFormContent: function _renderFormContent() {
      var formItemList = [];

      for (var index = 0; index < this.fieldList.length; index++) {
        var fieldItem = this.fieldList[index];
        formItemList.push(this._renderFormItem(fieldItem, index));
      }

      formItemList.push(this._renderFormFooter());
      return formItemList;
    },

    /**
     * 初始化表单的单项，可继承修改
     * @param fieldItem
     * @param index
     * @returns {null}
     * @private
     */
    // eslint-disable-next-line
    _renderFormItem: function _renderFormItem(fieldItem, index) {
      return null;
    },

    /**
     * 初始化表单footer的按钮部分，提交重置按钮，可继承修改
     * @returns {null}
     * @private
     */
    _renderFormFooter: function _renderFormFooter() {
      return null;
    },
    // 初始化表单item，一般无需继承修改
    _renderFormItemContent: function _renderFormItemContent(fieldItem) {
      var renderTypeMethodName = "_render".concat(fieldItem.type || 'OtherSlot'); // 有对应的绘制对应类型组件的方法则调用，无则返回空

      if (this[renderTypeMethodName]) {
        return this[renderTypeMethodName](fieldItem);
      } else {
        return null;
      }
    },
    // 初始化数字输入框
    _renderInputNumber: function _renderInputNumber(fieldItem) {
      var _this3 = this;

      return _vue.createVNode(_vue.resolveComponent("a-input-number"), _vue.mergeProps({
        props: fieldItem.props
      }, {
        "modelValue": _this3.form[fieldItem.key],
        "onUpdate:modelValue": function onUpdateModelValue($event) {
          return _this3.form[fieldItem.key] = $event;
        }
      }), null); // return (
      //   <div class="flex-h flex-vc">
      //     <a-input-number
      //       class="flex1"
      //       {...{ props: fieldItem.props }}
      //       vModel={this.form[fieldItem.key]}
      //     ></a-input-number>
      //     {fieldItem.suffix ? <span style="padding-left:5px;">{fieldItem.suffix}</span> : null}
      //   </div>
      // )
    },
    // 初始化输入框
    _renderInput: function _renderInput(fieldItem) {
      var _this4 = this;

      // attrs 可以传入使用未定义在props中的参数，props 只能传入定义过的参数
      return _vue.createVNode(_vue.resolveComponent("e-input"), _vue.mergeProps({
        props: fieldItem.props
      }, {
        "modelValue": _this4.form[fieldItem.key],
        "onUpdate:modelValue": function onUpdateModelValue($event) {
          return _this4.form[fieldItem.key] = $event;
        }
      }), null);
    },
    // 初始化单选按钮
    _renderRadio: function _renderRadio(fieldItem) {
      var _this5 = this;

      var props = fieldItem.props;
      return _vue.createVNode(_vue.resolveComponent("a-radio-group"), _vue.mergeProps({
        props: props
      }, {
        "value": this.form[fieldItem.key],
        "onChange": function onChange(e) {
          var value = e.target.value;
          var option = props.options.find(function (op) {
            return op.value === value;
          });
          _this5.labelForm[fieldItem.key] = option.label;

          _this5._emitChange(fieldItem.key, value, option.label, option);
        }
      }), null);
    },
    // 初始化下拉选择框
    _renderSelect: function _renderSelect(fieldItem) {
      var _this6 = this;

      return _vue.createVNode(_vue.resolveComponent("e-select"), _vue.mergeProps({
        props: fieldItem.props
      }, {
        "ref": fieldItem.key,
        "value": this.form[fieldItem.key],
        "onChange": function onChange(value, label, option) {
          _this6._selectChange(fieldItem, value, label, option);
        },
        "onLabelChange": function onLabelChange(label) {
          if (fieldItem.keys) {
            var labelKey = fieldItem.keys[0];
            var formLabel = _this6.form[labelKey];

            if (formLabel !== label) {
              _this6.form[labelKey] = label;
            }
          }
        }
      }), null);
    },
    // 初始化建议搜索框
    _renderSuggest: function _renderSuggest(fieldItem) {
      var _this7 = this;

      var keys = fieldItem.keys;
      var label = keys ? this.form[keys[0]] : undefined;
      return _vue.createVNode(_vue.resolveComponent("e-suggest-select"), _vue.mergeProps({
        props: fieldItem.props
      }, {
        "value": this.form[fieldItem.key],
        "label": label,
        "onChange": function onChange(value, label, option) {
          _this7._selectChange(fieldItem, value, label, option);
        }
      }), null);
    },
    // 初始化日期区间选择器
    _renderDateRange: function _renderDateRange(fieldItem) {
      var _this8 = this;

      var keys = fieldItem.keys;
      return _vue.createVNode(_vue.resolveComponent("e-date-range"), _vue.mergeProps({
        props: fieldItem.props
      }, {
        "startValue": this.form[keys[0]],
        "endValue": this.form[keys[1]],
        "onChange": function onChange(dates) {
          _this8._dateRangeChange(fieldItem, dates);
        }
      }), null);
    },
    // 初始化其他类型的插槽
    _renderOtherSlot: function _renderOtherSlot(fieldItem) {
      var key = fieldItem.key;

      if (this.$scopedSlots[key]) {
        return this.$scopedSlots[key]({
          data: this.form,
          item: fieldItem
        });
      } else {
        return null;
      }
    },

    /**
     * 下拉选择变动, select, suggest-select, cascader
     * @param item
     * @param value 下拉的value
     * @param label 下拉的label
     * @param option 选中的数据对象
     * @private
     */
    _selectChange: function _selectChange(item, value, label, option) {
      if (item.keys) {
        this.$set(this.form, item.keys[0], label); // this.form[item.keys[0]] = label
      }

      this.labelForm[item.key] = label;

      this._emitChange(item.key, value, label, option);
    },

    /**
     * 时间区间选择变动
     * @param key form的key
     * @param {Array} dates 指定日期格式的字符串，无格式则返回moment
     * @private
     */
    _dateRangeChange: function _dateRangeChange(item, dates) {
      var _this9 = this;

      var keys = item.keys,
          key = item.key;
      this.$set(this.form, key, 'date');
      dates.forEach(function (date, index) {
        // this.$set(this.form, keys[index], date)
        _this9._emitChange(keys[index], date);
      });
    },

    /**
     * 向外发送变动事件
     * @param key 变动的表单项的key
     * @param value 变动的值
     * @param label 如果是下拉有变动的label
     * @param option 如果是下拉选中的数据
     * @private
     */
    _emitChange: function _emitChange(key, value, label, option) {
      if (this.form[key] !== value) {
        this.$set(this.form, key, value);
        this.$emit('change', {
          key: key,
          value: value,
          label: label,
          option: option,
          form: this.form
        });
      }
    },

    /**
     * 获取字典列表数据，use组件时需要重写此方法
     * @param dictId
     * @returns {Promise<*[]>}
     */
    // eslint-disable-next-line
    getDictList: function getDictList(dictId) {
      // this.$store
      //   .dispatch('GetDictList', item.dictId)
      return Promise.resolve([]);
    },

    /**
     * 表单校验结果
     * @returns {Promise<any>}
     */
    validate: function validate() {
      var _this10 = this;

      return new Promise(function (resolve, reject) {
        _this10.$refs.advancedForm.validate(function (valid) {
          _this10.validError = !valid;

          if (valid) {
            resolve(true);
          } else {
            reject(new Error('表单校验失败'));
          }
        });
      });
    },

    /**
     * 重置校验结果
     */
    clearValidate: function clearValidate(propList) {
      if (propList) {
        this.validError = false;
        this.$refs.advancedForm.clearValidate(propList);
      } else {
        this.$refs.advancedForm.clearValidate();
      }
    },

    /**
     * 重置表单
     */
    reset: function reset() {
      this.form = {};
      this.clearValidate();
    },

    /**
     * 更新form数据
     * @param dataForm
     */
    setDataForm: function setDataForm(dataForm) {
      this.form = _extends({}, dataForm);
    },

    /**
     * 获取表单数据，可继承修改
     * @returns {form|{}}
     */
    getValue: function getValue() {
      return this.form;
    }
  }
};

==> better-admin-ui-vue-0.0.4.tgz: package/es/components/Form/Form.mixin.js <==
import _mergeJSXProps6 from "babel-helper-vue-jsx-merge-props";
import _mergeJSXProps5 from "babel-helper-vue-jsx-merge-props";
import _mergeJSXProps4 from "babel-helper-vue-jsx-merge-props";
import _mergeJSXProps3 from "babel-helper-vue-jsx-merge-props";
import _mergeJSXProps2 from "babel-helper-vue-jsx-merge-props";
import _mergeJSXProps from "babel-helper-vue-jsx-merge-props";

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? Object(arguments[i]) : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

/**
 * @Date: 2020-05-20 09:42
 * @Author: Fioanna
 * @Description: 高级表单混入
 */
import AInputNumber from 'ant-design-vue/es/input-number';
import { Group as ARadioGroup } from 'ant-design-vue/es/radio';
import { isChooseType, getDefaultPlaceholder } from './constants';
import { formMixinProps } from './types';
import EDateRange from '../DateRange/DateRange';
import EInput from '../Input/Input';
import ESelect from '../Select/Select';
import ESuggestSelect from '../SuggestSelect/SuggestSelect';
import './style.less';
export default {
  name: 'EFormMixin',
  props: formMixinProps,
  data: function data() {
    return {
      fieldList: [],
      // 表单的itemName列表
      form: {},
      // 表单数据
      labelForm: {} // 选择器展示文字的集合

    };
  },
  computed: {
    // filedList是否有数据
    hasFieldList: function hasFieldList() {
      return this.fieldList && this.fieldList.length > 0;
    },
    // 表单v-bind的所有props
    formModelBind: function formModelBind() {
      return {
        model: this.form
      };
    }
  },
  watch: {
    list: function list(newVal) {
      this._parseFieldList(newVal, this.form);
    },
    // 先注释掉，如果打开会引起整个form的dom重新刷新。暂时没有测出问题
    formData: function formData(newVal) {
      if (newVal) {
        // 数据更新合并
        this.form = _extends({}, this.form, newVal);
      }
    }
  },
  created: function created() {
    this.validError = false;

    this._parseFieldList(this.list, this.formData);
  },
  methods: {
    /**
     * 解析表单参数列表,获取字典列表
     * @private
     */
    _parseFieldList: function _parseFieldList(list, formData) {
      var _this = this;

      if (list && list.length > 0) {
        var newForm = _extends({}, formData);

        var fieldList = [];
        this.list.forEach(function (item) {
          if (!item.hidden) {
            // 不隐藏的
            var type = item.type;
            var props = _objectSpread({}, item.props) || {}; // 如果item中有options时，则设置到props中去

            if (item.options) {
              props.options = _toConsumableArray(item.options);
            }

            var newItem = _objectSpread({}, item, {
              props: props
            }); // 如果原本没有palceholder则设置默认的palceholder


            if (!props.placeholder) {
              props.placeholder = item.placeholder || getDefaultPlaceholder(type) + item.label;
            } // 如果必输，设置rules


            if (item.required) {
              newItem.rules = newForm.rules || [];
              newItem.rules.unshift({
                required: true,
                message: props.placeholder,
                trigger: isChooseType(type) ? 'change' : 'blur'
              });
            }

            props.disabled = _this._isDisabled(item); // 是否有对应类型解析数据到方法，有则调用

            var parseTypeMethodName = "_parse".concat(type);

            if (_this[parseTypeMethodName]) {
              _this[parseTypeMethodName](item, props, newForm, newItem);
            }

            fieldList.push(newItem);
          }
        });
        this.fieldList = fieldList;
        this.form = newForm;

        this._doAfterParseFieldList();
      }
    },

    /**
     * 解析完表单项列表的操作，可继承修改
     * @private
     */
    _doAfterParseFieldList: function _doAfterParseFieldList() {},

    /**
     * 判断formItem是否不可编辑，可继承修改
     * @param fieldItem
     * @returns {boolean}
     * @private
     */
    _isDisabled: function _isDisabled(fieldItem) {
      if (fieldItem.props && fieldItem.props.disabled) {
        // 如果该项的属性就是不可编辑返回true
        return true;
      }

      return false;
    },
    // 下拉多选
    _parseSelect: function _parseSelect(item, props, newForm) {
      var _this2 = this;

      // 下拉选项，且有字典值则从协议获取数据
      if (item.dictId) {
        props.valueName = 'name';
        props.labelName = 'caption';
        this.getDictList(item.dictId).then(function (list) {
          _this2._refreshDictSelectList(list, item, props);
        })["catch"](function () {});
      } else {
        this._refreshSelectList(props.options, item, props);
      } // 下拉需要初始化值


      if (item.init && newForm[item.key] === undefined) {
        newForm[item.key] = props.options[0].value;
      }
    },
    // 单选
    _parseRadio: function _parseRadio(item, props, newForm) {
      // 单选需要初始化值
      if (item.init && newForm[item.key] === undefined) {
        newForm[item.key] = props.options[0].value;
      }
    },
    // 时间选择器
    _parseDateRange: function _parseDateRange(item, props, newForm, newItem) {
      var key = newItem.key;

      if (!newItem.keys) {
        newItem.keys = [key + '1', key + '2'];
      }

      var keys = newItem.keys;

      if (newForm[keys[0]] && newForm[keys[1]]) {
        newForm[key] = 'true';
      }
    },

    /**
     * 刷新普通下拉选项列表，可继承
     */
    // eslint-disable-next-line
    _refreshSelectList: function _refreshSelectList(selectList, item, props) {},

    /**
     * 刷新字典下拉选项列表，可继承
     */
    // eslint-disable-next-line
    _refreshDictSelectList: function _refreshDictSelectList(selectList, item, props) {
      var itemDom = this.$refs[item.key]; // 直接更新下拉组件中的数据

      if (itemDom) {
        itemDom.setOptionList(selectList);
      }
    },
    // 初始化表单各项内容
    _renderFormContent: function _renderFormContent() {
      var formItemList = [];

      for (var index = 0; index < this.fieldList.length; index++) {
        var fieldItem = this.fieldList[index];
        formItemList.push(this._renderFormItem(fieldItem, index));
      }

      formItemList.push(this._renderFormFooter());
      return formItemList;
    },

    /**
     * 初始化表单的单项，可继承修改
     * @param fieldItem
     * @param index
     * @returns {null}
     * @private
     */
    // eslint-disable-next-line
    _renderFormItem: function _renderFormItem(fieldItem, index) {
      return null;
    },

    /**
     * 初始化表单footer的按钮部分，提交重置按钮，可继承修改
     * @returns {null}
     * @private
     */
    _renderFormFooter: function _renderFormFooter() {
      return null;
    },
    // 初始化表单item，一般无需继承修改
    _renderFormItemContent: function _renderFormItemContent(fieldItem) {
      var renderTypeMethodName = "_render".concat(fieldItem.type || 'OtherSlot'); // 有对应的绘制对应类型组件的方法则调用，无则返回空

      if (this[renderTypeMethodName]) {
        return this[renderTypeMethodName](fieldItem);
      } else {
        return null;
      }
    },
    // 初始化数字输入框
    _renderInputNumber: function _renderInputNumber(fieldItem) {
      var h = this.$createElement;
      return h(AInputNumber, _mergeJSXProps([{
        props: fieldItem.props
      }, {
        attrs: {
          vModel: this.form[fieldItem.key]
        }
      }])); // return (
      //   <div class="flex-h flex-vc">
      //     <a-input-number
      //       class="flex1"
      //       {...{ props: fieldItem.props }}
      //       vModel={this.form[fieldItem.key]}
      //     ></a-input-number>
      //     {fieldItem.suffix ? <span style="padding-left:5px;">{fieldItem.suffix}</span> : null}
      //   </div>
      // )
    },
    // 初始化输入框
    _renderInput: function _renderInput(fieldItem) {
      var h = this.$createElement;
      // attrs 可以传入使用未定义在props中的参数，props 只能传入定义过的参数
      return h(EInput, _mergeJSXProps2([{
        props: fieldItem.props
      }, {
        attrs: {
          vModel: this.form[fieldItem.key]
        }
      }]));
    },
    // 初始化单选按钮
    _renderRadio: function _renderRadio(fieldItem) {
      var _this3 = this;

      var h = this.$createElement;
      var props = fieldItem.props;
      return h(ARadioGroup, _mergeJSXProps3([{
        props: props
      }, {
        attrs: {
          value: this.form[fieldItem.key]
        },
        on: {
          "change": function change(e) {
            var value = e.target.value;
            var option = props.options.find(function (op) {
              return op.value === value;
            });
            _this3.labelForm[fieldItem.key] = option.label;

            _this3._emitChange(fieldItem.key, value, option.label, option);
          }
        }
      }]));
    },
    // 初始化下拉选择框
    _renderSelect: function _renderSelect(fieldItem) {
      var _this4 = this;

      var h = this.$createElement;
      return h(ESelect, _mergeJSXProps4([{
        ref: fieldItem.key
      }, {
        props: fieldItem.props
      }, {
        attrs: {
          value: this.form[fieldItem.key]
        },
        on: {
          "change": function change(value, label, option) {
            _this4._selectChange(fieldItem, value, label, option);
          },
          "labelChange": function labelChange(label) {
            if (fieldItem.keys) {
              var labelKey = fieldItem.keys[0];
              var formLabel = _this4.form[labelKey];

              if (formLabel !== label) {
                _this4.form[labelKey] = label;
              }
            }
          }
        }
      }]));
    },
    // 初始化建议搜索框
    _renderSuggest: function _renderSuggest(fieldItem) {
      var _this5 = this;

      var h = this.$createElement;
      var keys = fieldItem.keys;
      var label = keys ? this.form[keys[0]] : undefined;
      return h(ESuggestSelect, _mergeJSXProps5([{
        props: fieldItem.props
      }, {
        attrs: {
          value: this.form[fieldItem.key],
          label: label
        },
        on: {
          "change": function change(value, label, option) {
            _this5._selectChange(fieldItem, value, label, option);
          }
        }
      }]));
    },
    // 初始化日期区间选择器
    _renderDateRange: function _renderDateRange(fieldItem) {
      var _this6 = this;

      var h = this.$createElement;
      var keys = fieldItem.keys;
      return h(EDateRange, _mergeJSXProps6([{
        props: fieldItem.props
      }, {
        attrs: {
          startValue: this.form[keys[0]],
          endValue: this.form[keys[1]]
        },
        on: {
          "change": function change(dates) {
            _this6._dateRangeChange(fieldItem, dates);
          }
        }
      }]));
    },
    // 初始化其他类型的插槽
    _renderOtherSlot: function _renderOtherSlot(fieldItem) {
      var key = fieldItem.key;

      if (this.$scopedSlots[key]) {
        return this.$scopedSlots[key]({
          data: this.form,
          item: fieldItem
        });
      } else {
        return null;
      }
    },

    /**
     * 下拉选择变动, select, suggest-select, cascader
     * @param item
     * @param value 下拉的value
     * @param label 下拉的label
     * @param option 选中的数据对象
     * @private
     */
    _selectChange: function _selectChange(item, value, label, option) {
      if (item.keys) {
        this.$set(this.form, item.keys[0], label); // this.form[item.keys[0]] = label
      }

      this.labelForm[item.key] = label;

      this._emitChange(item.key, value, label, option);
    },

    /**
     * 时间区间选择变动
     * @param key form的key
     * @param {Array} dates 指定日期格式的字符串，无格式则返回moment
     * @private
     */
    _dateRangeChange: function _dateRangeChange(item, dates) {
      var _this7 = this;

      var keys = item.keys,
          key = item.key;
      this.$set(this.form, key, 'date');
      dates.forEach(function (date, index) {
        // this.$set(this.form, keys[index], date)
        _this7._emitChange(keys[index], date);
      });
    },

    /**
     * 向外发送变动事件
     * @param key 变动的表单项的key
     * @param value 变动的值
     * @param label 如果是下拉有变动的label
     * @param option 如果是下拉选中的数据
     * @private
     */
    _emitChange: function _emitChange(key, value, label, option) {
      if (this.form[key] !== value) {
        this.$set(this.form, key, value);
        this.$emit('change', {
          key: key,
          value: value,
          label: label,
          option: option,
          form: this.form
        });
      }
    },

    /**
     * 获取字典列表数据，use组件时需要重写此方法
     * @param dictId
     * @returns {Promise<*[]>}
     */
    // eslint-disable-next-line
    getDictList: function getDictList(dictId) {
      // this.$store
      //   .dispatch('GetDictList', item.dictId)
      return Promise.resolve([]);
    },

    /**
     * 表单校验结果
     * @returns {Promise<any>}
     */
    validate: function validate() {
      var _this8 = this;

      return new Promise(function (resolve, reject) {
        _this8.$refs.advancedForm.validate(function (valid) {
          _this8.validError = !valid;

          if (valid) {
            resolve(true);
          } else {
            reject(new Error('表单校验失败'));
          }
        });
      });
    },

    /**
     * 重置校验结果
     */
    clearValidate: function clearValidate(propList) {
      if (propList) {
        this.validError = false;
        this.$refs.advancedForm.clearValidate(propList);
      } else {
        this.$refs.advancedForm.clearValidate();
      }
    },

    /**
     * 重置表单
     */
    reset: function reset() {
      this.form = {};
      this.clearValidate();
    },

    /**
     * 更新form数据
     * @param dataForm
     */
    setDataForm: function setDataForm(dataForm) {
      this.form = _extends({}, dataForm);
    },

    /**
     * 获取表单数据，可继承修改
     * @returns {form|{}}
     */
    getValue: function getValue() {
      return this.form;
    }
  }
};
